server_client_20141211_175217

### config1 : test_client_timeout

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 61.212043047 sec | 64.2704291344 sec

Error message: Did not properly handle client timeout

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 0.2 | 0.092 | 0.068 | 0.085 | 0.1 | 0.11 | 0.12 | 0.14 | 0.017
qps | 865.00 | 333.67 | 53.00 | 83.00 | 474.00 | 708.60 | 786.80 | 849.36 | 375.91

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 1208.80 | 1208.80 | 1208.80 | 1208.80 | 1208.80 | 1208.80 | 1208.80 | 1208.80 | 0.0
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.085
server1-perf | latency | mean lt 0.33 | 0.0922597402597
server1-perf | qps | mean lt 7.0 | 333.666666667
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 1208.8
client1-perf | latency | mean lt 35.0 | 1208.8
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None